@@ -135,7 +135,7 @@ atk_relation_type_get_name (AtkRelationType type)
 {
   GTypeClass *type_class;
   GEnumValue *value;
-  gchar *name = NULL;
+  const gchar *name = NULL;
 
   type_class = g_type_class_ref (ATK_TYPE_RELATION_TYPE);
   g_return_val_if_fail (G_IS_ENUM_CLASS (type_class), NULL);
